@@ -4,7 +4,8 @@ function(x, dframe=mydata,
          col.slices=NULL, col.low=NULL, col.hi=NULL,
          colors=c("blue", "gray", "rose", "green", "gold", "red",
                   "rainbow", "terrain", "heat"),
-         text.out=TRUE, main=NULL, ...) {
+         text.out=TRUE, main=NULL,
+         pdf.file=NULL, pdf.width=5, pdf.height=5, ...) {
 
 
   colors <- match.arg(colors)
@@ -30,9 +31,21 @@ function(x, dframe=mydata,
     if (is.function(x.call)) x.call <- eval(substitute(dframe$x))
   }
 
-  .graphwin()
+  # set up graphics system
+  .opendev(pdf.file, pdf.width, pdf.height)
+
+  #orig.params <- par(no.readonly=TRUE)
+  #on.exit(par(orig.params))
+
   .pc.main(x.call, 
        random.col, col.slices, col.low, col.hi,
-       colors, text.out, main, ...)
+       colors, text.out, main, 
+       pdf.file, pdf.width, pdf.height, ...)
+
+  # terminate pdf graphics system
+  if (!is.null(pdf.file)) {
+    dev.off()
+    .showfile(pdf.file, "pie chart")
+  }
 
 }
