@@ -139,11 +139,15 @@ function(my.formula, dframe=mydata, digits.d=4, text.width=120,
          cor, collinear, subsets, numeric.all, in.data.frame)
   
 
-  if (res.rows > 0)  # two plots here
+  if (res.rows > 0) {  # two plots here
+
+    if (!pdf) .graphwin(3)  # set up graphics system
+
     .reg3Residual(nm, mydframe,
          n.vars, n.pred, n.obs, n.keep, digits.d, explain, show.R, pre, line,
          res.sort, res.rows, cooks.cut, colors,
          pdf, pdf.width, pdf.height)
+   }
  
 
   if (pred)
