@@ -1,65 +1,27 @@
 .plt.main <- 
-function(x, y=NULL, dframe, type, ncut,
-       col.line, col.area, col.box, col.pts, col.fill, trans.pts,
-       pch, col.grid, col.bg, colors, cex.axis, col.axis, col.ticks, xy.ticks,
-       xlab, ylab, main, cex, x.start, x.end, y.start, y.end,
-       time.start, time.by, time.reverse, kind,
-       fit.line, col.fit.line, center.line, col.bubble, bubble.size, col.flower,
-       ellipse, col.ellipse, fill.ellipse, text.out, ...) {
+function(x, y, by, dframe, type, n.cat,
+         col.line, col.area, col.box, col.pts, col.fill,
+         trans.pts, shape.pts, col.grid, col.bg, colors, 
+         cex.axis, col.axis, col.ticks, 
+         xy.ticks, xlab, ylab, main, cex,
+         x.start, x.end, y.start, y.end, kind,
+         fit.line, col.fit.line,
+         col.bubble, bubble.size, col.flower,
+         ellipse, col.ellipse, fill.ellipse, text.out, ...) {
 
-  old.par <- par(no.readonly = TRUE)  # save all modifiable settings
-  on.exit(par(old.par))
-
-  old.opt <- options()
-  on.exit(options(old.opt))
-
-  if (!is.null(trans.pts)) options(trans=trans.pts)
-  else if (is.null(getOption("trans"))) options(trans=0.66)  # default
-
-  if (is.null(y)) if (is.factor(x)) { 
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "For a single variable plot, the variable must be numeric.\n\n")
-  }
-
-  if (!is.null(y)) if (is.factor(y)) { 
-    cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "The first variable can be an R factor (categorical),\n",
-        "but the second variable must be numeric.\n\n")
-  }
   if (!is.null(type)) if (type != "p" && type != "l" && type != "b") { 
     cat("\n"); stop(call.=FALSE, "\n","------\n",
         "Option 'type' can only be \"p\" for points,\n",
         "  \"l\" for line or \"b\" for both.\n\n")
   }
 
-  if (!is.null(center.line))
-    if (center.line != "mean" && center.line != "median" && center.line != "off") { 
-      cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "Option 'center.line' can only be \"mean\", \"median\", or \"off\".\n\n")
-  }
-      
-  if (!is.null(y)) {
-    txt <- "ignored when two variables are specified.\n"
-    if (!is.null(time.start)) cat("Warning: Option 'time.start'", txt)
-    if (!is.null(time.by)) cat("Warning: Option 'time.by'", txt)
-    if ((time.reverse)) cat("Warning: Option 'time.reverse'", txt)
-  }
-
-  if (!is.null(time.start) && is.null(time.by)) {
-     cat("\n"); stop(call.=FALSE, "\n","------\n",
-        "Specified  time.start  so also need  time.by.\n\n")
-  }
-      
-  #  pch=21 is a filled circle
-  if (is.null(pch)) point.type <- 21 else point.type <- pch
-
   nrows <- length(x)
   if (is.null(cex)) pt.size <- 0.8 else pt.size <- cex
 
   # color palette based on color theme colors
-  cp <- .clr(colors)
+  cp <- .clr(colors, trans.pts)
   if (is.null(col.pts)) col.pts <- cp[5]
-  if (is.null(col.fill)) if (!is.null(y)) col.fill <- cp[6] else col.fill <- cp[7]
+  if (is.null(col.fill)) col.fill <- cp[6]
   if (is.null(col.line)) col.line <- cp[5]
   if (is.null(col.bubble)) col.bubble <- cp[1]
   if (is.null(col.flower)) col.flower <- cp[2]
@@ -75,14 +37,15 @@ function(x, y=NULL, dframe, type, ncut,
   x.name <- gl$xn; x.lbl <- gl$xl; x.lab <- gl$xb
   y.name <- gl$yn; y.lbl <- gl$yl; y.lab <- gl$yb;
   main.lab <- gl$mb
+  by.name <- getOption("byname")
    
   nu <- length(unique(na.omit(x)))
-  if (is.numeric(x) && nu <= ncut) {
+  if (is.numeric(x) && nu <= n.cat) {
     x <- as.factor(x)
     cat("\n")
-    cat(">>> Variable is numeric, but only has", nu, "<= ncut =", ncut, "levels,",
+    cat(">>> Variable is numeric, but only has", nu, "<= n.cat =", n.cat, "levels,",
         "so treat as categorical.\n",
-        "   To treat as numeric, decrease  ncut  to specify a",
+        "   To treat as numeric, decrease  n.cat  to specify a",
         "lower number of unique values.\n",
         "   Suggest making this variable a factor with R factor function.\n")
    }
@@ -123,19 +86,22 @@ function(x, y=NULL, dframe, type, ncut,
   # -------------------------
   # plot
   # -------------------------
+
   # plot setup
   if (kind == "regular") {
+
+    if (!is.null(by)) par(omi=c(0,0,0,0.6))  # legend in right margin
+
     suppressWarnings(plot(x, y, type="n", axes=FALSE, xlab=x.lab, ylab=y.lab, 
              main=main.lab, ...))
     if (xy.ticks){
-      if (is.null(time.start) && class(x)!="ts") 
-        suppressWarnings(axis(1, cex.axis=cex.axis, col.axis=col.axis, 
+      suppressWarnings(axis(1, cex.axis=cex.axis, col.axis=col.axis, 
                          col.ticks=col.ticks, ...))
-      else axis.Date(1, x, cex.axis=cex.axis, col.axis=col.axis, ...)
       suppressWarnings(axis(2, cex.axis=cex.axis, col.axis=col.axis, 
                        col.ticks=col.ticks, ...))
     }
   }
+
   else if (kind == "xcat") {
     plot.default(y ~ x, xlim=c(.5,nlevels(x)+.5), type="n", axes=FALSE, 
                  main=main.lab, xlab=x.lab, ylab=y.lab)
@@ -143,6 +109,7 @@ function(x, y=NULL, dframe, type, ncut,
     axis(1, labels=levels(x), at=1:nlevels(x), 
             cex.axis=cex.axis, col.axis=col.axis, col.ticks=col.ticks)
   }
+
   else if ((kind == "bubble") || (kind == "sunflower")) {
     mytbl <- table(x, y)  # get the counts
     x.lo <- x.start-.5
@@ -170,7 +137,11 @@ function(x, y=NULL, dframe, type, ncut,
            xlim=c(x.lo,x.hi), ylim=c(y.lo,y.hi), cex.axis=cex.axis, 
            col.axis=col.axis)
   }
-  else cat("This type of plot not recognized:", kind, "\n")
+
+  else {
+    cat("\n"); stop(call.=FALSE, "\n","------\n",
+    "This type of plot not recognized: ", kind, "\n\n")
+  }
 
 
   # colored plotting area
@@ -195,8 +166,43 @@ function(x, y=NULL, dframe, type, ncut,
       lines(as.numeric(x),y, col=col.line, ...)
     }
     if (type == "p" | type == "b") {
-      suppressWarnings(points(x,y, col=col.pts, pch=point.type, bg=col.fill, 
-                       cex=pt.size, ...))
+
+      if (is.null(by)) 
+        suppressWarnings(points(x,y, pch=shape.pts, col=col.pts, bg=col.fill, 
+                         cex=pt.size, ...))
+
+      else {  # by grouping variable
+        n.levels <- nlevels(by)
+
+        clr <- character(length(n.levels))
+        if (length(col.pts) == 1) 
+          for (i in 1:n.levels) clr[i] <- col.pts
+        else
+          clr <- col.pts
+        clr.tr <- clr
+
+        shp <- integer(length(n.levels))
+        if (length(shape.pts) == 1)
+          for (i in 1:n.levels) shp[i] <- shape.pts
+        else
+           shp <- shape.pts
+        shape.dft <- c(21,23,22,24,25,7:14)  # shape defaults
+        if (length(col.pts)==1 && length(shape.pts)==1)  # both shape and color default
+          for (i in 1:n.levels) shp[i] <- shape.dft[i]  # fill with default shapes
+
+        for (i in 1:n.levels) {
+          clr.tr[i] <- .maketrans(clr.tr[i], trans.pts)
+          x.lv <- subset(x, by==levels(by)[i])
+          y.lv <- subset(y, by==levels(by)[i])
+          points(x.lv, y.lv, pch=shp[i], col=clr[i], bg=clr.tr[i], 
+                 cex=pt.size, lwd=0.75, ...)
+        }
+        cat("\nTransparency level for plotted points: ", trans.pts, "\n\n")
+
+      .plt.legend(levels(by), col.pts, clr, clr.tr, shp, trans.pts, col.bg, usr)
+
+      }  # end by group
+
       if (ellipse) {
         n.del <- sum(is.na(x - y))  # number missing
         if (n.del == 0)
@@ -207,7 +213,8 @@ function(x, y=NULL, dframe, type, ncut,
           cat("\n>>>Note: Ellipse function does not work with missing data.\n")
       }
     }
-  }
+  }  # kind = "regular"
+
   else if (kind == "xcat") {  # plot means
     for (i in (1:nlevels(x))) {
       m.lvl <- mean(y[x==levels(x)[i]], na.rm=TRUE)
@@ -216,6 +223,7 @@ function(x, y=NULL, dframe, type, ncut,
       points(i, m.lvl, pch=23, bg=col.symbol)
     }
   }
+
   else if (kind == "bubble") {
     symbols(cords$xx, cords$yy, circles=cords$count, bg=col.bubble, 
             inches=bubble.size, add=TRUE, ...)
@@ -226,6 +234,7 @@ function(x, y=NULL, dframe, type, ncut,
         fill.alpha=.06, center.cex=0, segments=100, plot.points=FALSE)
     }
   }
+
   else if (kind == "sunflower") {
     sunflowerplot(cords$xx, cords$yy, number=cords$count, 
       seg.col=col.flower, col=col.flower, cex.axis=cex.axis, col.axis=col.axis,
@@ -235,7 +244,7 @@ function(x, y=NULL, dframe, type, ncut,
   # fit line option
   if (fit.line != "none") {  
     ok <- is.finite(x) & is.finite(y)
-    if (any(ok))
+    if (any(ok)) {
       x.ok <- x[ok]
       y.ok <- y[ok]
       ord <- order(x.ok)
@@ -249,8 +258,9 @@ function(x, y=NULL, dframe, type, ncut,
           model <- lm(y.ord ~ x.ord)
           abline(model$coef, col=col.fit.line)
         }
-        else cat("\nLeast squares line not permitted for a factor.\n")
+        else cat("\n>>> Note: Least squares line not permitted for a factor.\n")
       }
+    }
   }
 
   # correlation
