@@ -1,4 +1,4 @@
 rad.both <-
 function(ref=NULL, data=TRUE, labels=TRUE, ...)
 
-rad(ref, data=TRUE, labels=TRUE, ...)
+Read(ref, data=TRUE, labels=TRUE, ...)
