@@ -1,6 +1,6 @@
 rad2 <- 
 function(ref=NULL, sep=";", dec=",", ...) {
          
-  rad(ref, sep=";", dec=",", ...)
+  Read(ref, sep=";", dec=",", ...)
 
 }
