@@ -1,5 +1,5 @@
 reg.brief <-
 function(my.formula, brief=TRUE, ...)
 
-reg(my.formula, brief=TRUE, ...)
+  Regression(my.formula, brief=TRUE, ...)
 
