@@ -72,17 +72,15 @@ function(nm, mydframe,
     rm(out)
   
 
-    if (!pdf) {
-      .graphwin(3)  # set up graphics system
+    # frequency distribution of residuals
+    if (!pdf) 
       dev.set(which=3)
-    }
-    else { 
+    else {
       pdf.file <- "RegResiduals.pdf"
       pdf(file=pdf.file, width=pdf.width, height=pdf.height)
     }
-  
-    # frequency distribution of residuals
-    .den.main(res, main="Evaluate Normality of Residuals", 
+
+     .den.main(res, main="Evaluate Normality of Residuals", 
        xlab="Residuals", text.out=FALSE, colors=colors,
        bw="nrd0", type="both",
        bin.start=NULL, bin.width=NULL,
